@@ -9,11 +9,20 @@ def list_files(dataset_id):
 def matched_files(dataset_id):
     return 'datasets/{}/download_files'.format(dataset_id)
 
-def pif_dataset_uid(dataset_id, pif_uid):
-    return 'datasets/{}/pif/{}'.format(dataset_id, pif_uid)
+def pif_dataset_uid(dataset_id, pif_uid, pif_version = None, with_metadata = False):
+    url = 'datasets/{}/pif/{}'.format(dataset_id, pif_uid)
+    return _get_pif_url_helper(url, pif_version, with_metadata)
 
-def pif_dataset_version_uid(dataset_id, version, pif_uid):
-    return 'datasets/{}/version/{}/pif/{}'.format(dataset_id, version, pif_uid)
+def pif_dataset_version_uid(dataset_id, version, pif_uid, pif_version = None, with_metadata = False):
+    url = 'datasets/{}/version/{}/pif/{}'.format(dataset_id, version, pif_uid)
+    return _get_pif_url_helper(url, pif_version, with_metadata)
+
+def _get_pif_url_helper(url, pif_version, with_metadata):
+    if pif_version:
+        url += '/pif-version/{}'.format(pif_version)
+    if with_metadata:
+        url += '?with-metadata=true'
+    return url
 
 def create_dataset():
     return 'data_sets/create_dataset'
